==> jasperreports-chart-customizers-6.21.3-sources.jar: net/sf/jasperreports/customizers/type/RectangleAnchorEnum.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2023 Cloud Software Group, Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.customizers.type;

import org.jfree.ui.RectangleAnchor;

import net.sf.jasperreports.engine.type.EnumUtil;
import net.sf.jasperreports.engine.type.NamedEnum;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 */
public enum RectangleAnchorEnum implements NamedEnum
{
	/**
	 *
	 */
	TOP(RectangleAnchor.TOP, "top"),

	/**
	 *
	 */
	TOP_LEFT(RectangleAnchor.TOP_LEFT, "topLeft"),

	/**
	 *
	 */
	TOP_RIGHT(RectangleAnchor.TOP_RIGHT, "topRight"),

	/**
	 *
	 */
	BOTTOM(RectangleAnchor.BOTTOM, "bottom"),

	/**
	 *
	 */
	BOTTOM_LEFT(RectangleAnchor.BOTTOM_LEFT, "bottomLeft"),

	/**
	 *
	 */
	BOTTOM_RIGHT(RectangleAnchor.BOTTOM_RIGHT, "bottom-rigth"),

	/**
	 *
	 */
	CENTER(RectangleAnchor.CENTER, "center"),

	/**
	 *
	 */
	LEFT(RectangleAnchor.LEFT, "left"),

	/**
	 *
	 */
	RIGHT(RectangleAnchor.RIGHT, "right");


	/**
	 *
	 */
	private final transient RectangleAnchor value;
	private final transient String name;

	private RectangleAnchorEnum(RectangleAnchor rectangleAnchor, String name)
	{
		this.value = rectangleAnchor;
		this.name = name;
	}

	@Override
	public String getName()
	{
		return name;
	}

	/**
	 *
	 */
	public final RectangleAnchor getRectangleAnchor()
	{
		return this.value;
	}

	/**
	 *
	 */
	public static RectangleAnchorEnum getByName(String name)
	{
		return EnumUtil.getEnumByName(values(), name);
	}
}

==> jasperreports-chart-customizers-7.0.3-sources.jar: net/sf/jasperreports/customizers/type/RectangleAnchorEnum.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2025 Cloud Software Group, Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.customizers.type;

import org.jfree.chart.ui.RectangleAnchor;

import net.sf.jasperreports.engine.type.EnumUtil;
import net.sf.jasperreports.engine.type.NamedEnum;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 */
public enum RectangleAnchorEnum implements NamedEnum
{
	/**
	 *
	 */
	TOP(RectangleAnchor.TOP, "top"),

	/**
	 *
	 */
	TOP_LEFT(RectangleAnchor.TOP_LEFT, "topLeft"),

	/**
	 *
	 */
	TOP_RIGHT(RectangleAnchor.TOP_RIGHT, "topRight"),

	/**
	 *
	 */
	BOTTOM(RectangleAnchor.BOTTOM, "bottom"),

	/**
	 *
	 */
	BOTTOM_LEFT(RectangleAnchor.BOTTOM_LEFT, "bottomLeft"),

	/**
	 *
	 */
	BOTTOM_RIGHT(RectangleAnchor.BOTTOM_RIGHT, "bottom-rigth"),

	/**
	 *
	 */
	CENTER(RectangleAnchor.CENTER, "center"),

	/**
	 *
	 */
	LEFT(RectangleAnchor.LEFT, "left"),

	/**
	 *
	 */
	RIGHT(RectangleAnchor.RIGHT, "right");


	/**
	 *
	 */
	private final transient RectangleAnchor value;
	private final transient String name;

	private RectangleAnchorEnum(RectangleAnchor rectangleAnchor, String name)
	{
		this.value = rectangleAnchor;
		this.name = name;
	}

	@Override
	public String getName()
	{
		return name;
	}

	/**
	 *
	 */
	public final RectangleAnchor getRectangleAnchor()
	{
		return this.value;
	}

	/**
	 *
	 */
	public static RectangleAnchorEnum getByName(String name)
	{
		return EnumUtil.getEnumByName(values(), name);
	}
}
